#!/usr/bin/python
# -*- coding: UTF-8 -*-

from lltk.helpers import download, play

from google import google
from forvo import forvo
